@@ -612,7 +612,11 @@ async def handle_websocket_message(message: Dict[str, Any], websocket: WebSocket
                             status = {"status": "completed", "message": client.task_manager.message}
                         else:
                             status = {"status": "completed", "message": "Goal completed"}
-                
+                    elif client.is_running:
+                        status = {"status": "running", "message": client.log_handler.current_step}
+                    else:
+                        status = {"status": "ready", "message": "Ready"}
+
                 response = {
                     "type": "agent_status_response",
                     "status": "success",
