@@ -69,7 +69,7 @@ async function selectClient(id){
   // Start polling if agent is running
   if (c.is_running) {
     updateAgentStatus({ status: 'running', message: c.active_goal || 'Running...' });
-    startAgentStatusPolling();
+    //startAgentStatusPolling();
   }
 }
 
@@ -221,7 +221,7 @@ async function sendGoal(){
     });
     
     // Start polling for agent status updates
-    startAgentStatusPolling();
+    //startAgentStatusPolling();
     
     // Update UI to show agent is starting
     updateAgentStatus({ status: 'running', message: 'Starting agent...' });
